aboutsummaryrefslogtreecommitdiff
path: root/src/cmd/internal/objabi/stack.go
diff options
context:
space:
mode:
authorDamien Neil <dneil@google.com>2024-12-02 12:45:55 -0800
committerGopher Robot <gobot@golang.org>2024-12-06 00:35:41 +0000
commit4da905bcf07d80eb62be5cb996e11a89258364ad (patch)
tree2c97507472da8378f65bf6cb026af7340f431d02 /src/cmd/internal/objabi/stack.go
parentea867378100acaa01291696ba6047b7ea766839e (diff)
downloadgo-4da905bcf07d80eb62be5cb996e11a89258364ad.tar.xz
cmd/internal/objabi, internal/runtime: increase nosplit limit on OpenBSD
OpenBSD is bumping up against the nosplit limit, and openbsd/ppc64 is over it. Increase StackGuardMultiplier on OpenBSD, matching AIX. Change-Id: I61e17c99ce77e1fd3f368159dc4615aeae99e913 Reviewed-on: https://go-review.googlesource.com/c/go/+/632996 Reviewed-by: Keith Randall <khr@golang.org> Reviewed-by: Keith Randall <khr@google.com> Auto-Submit: Damien Neil <dneil@google.com> LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Reviewed-by: Cherry Mui <cherryyz@google.com>
Diffstat (limited to 'src/cmd/internal/objabi/stack.go')
-rw-r--r--src/cmd/internal/objabi/stack.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cmd/internal/objabi/stack.go b/src/cmd/internal/objabi/stack.go
index d50a7c1afd..6a1edd46c8 100644
--- a/src/cmd/internal/objabi/stack.go
+++ b/src/cmd/internal/objabi/stack.go
@@ -20,8 +20,8 @@ func StackNosplit(race bool) int {
func stackGuardMultiplier(race bool) int {
// This arithmetic must match that in internal/runtime/sys/consts.go:StackGuardMultiplier.
n := 1
- // On AIX, a larger stack is needed for syscalls.
- if buildcfg.GOOS == "aix" {
+ // On AIX and OpenBSD, a larger stack is needed for syscalls.
+ if buildcfg.GOOS == "aix" || buildcfg.GOOS == "openbsd" {
n += 1
}
// The race build also needs more stack.